@@ -2,7 +2,7 @@ context("Compute hydat peak frequencies")
 
 test_that("creates a list with the proper objects", {
   skip_on_cran()
-  skip_on_travis()
+  skip_on_ci()
   data <- suppressMessages(suppressWarnings(
     compute_hydat_peak_frequencies(station_number = "08NM116", 
                                          start_year = 1980, use_max = TRUE)))
@@ -12,7 +12,7 @@ test_that("creates a list with the proper objects", {
 
 test_that("creates proper object classes", {
   skip_on_cran()
-  skip_on_travis()
+  skip_on_ci()
   data <- suppressMessages(suppressWarnings(
     compute_hydat_peak_frequencies(station_number = "08NM116", 
                                          start_year = 1980, use_max = TRUE)))
@@ -21,4 +21,4 @@ test_that("creates proper object classes", {
   expect_true("gg" %in% class(data$Freq_Plot))
   expect_true("list" %in% class(data$Freq_Fitting))
   expect_true("data.frame" %in% class(data$Freq_Fitted_Quantiles))
-})
\ No newline at end of file
+})
